@@ -1,14 +1,12 @@
-from typing import Type, TypeVar, Generic
+from typing import Type
 
 from BotCore import DataBase
 from BotCore.ModelInfo import ModelInfo
 
-T = TypeVar("T", bound=ModelInfo)
 
+class DAO:
 
-class DAO(Generic[T]):
-
-	def __init__(self, database: DataBase, model: Type[T]):
+	def __init__(self, database: DataBase, model: Type[ModelInfo]):
 		self.database: DataBase = database
 		self.model = model
 
