@@ -12,4 +12,5 @@ class ModelInfo:
 		raise NotImplementedError()
 
 	def __init__(self, data: dict[str, Any]):
-		self.__dict__.update(data)
+		for field in self.fields():
+			self.__setattr__(field, data.get(field))
