@@ -1,11 +1,8 @@
 
 from typing import TypeVar, Type, Generic
 
-from BotCore import DAO
-from BotCore.ModelInfo import ModelInfo
-
-T = TypeVar("T", bound=ModelInfo)
-D = TypeVar("D", bound=DAO)
+T = TypeVar("T")
+D = TypeVar("D")
 
 
 class Service(Generic[T, D]):
@@ -20,7 +17,7 @@ class Service(Generic[T, D]):
 	def delete(self, row_id):
 		return self.dao.delete(row_id)
 
-	def getall(self):
+	def getall(self) -> list[T]:
 		return self.dao.getall()
 
 	def to_objects(self, rows: list[tuple]) -> list[T]:
